@@ -1,7 +1,7 @@
-/* $Id: actions.c,v 1.48 2012/05/28 10:56:27 imilh Exp $ */
+/* $Id: actions.c,v 1.52 2012/07/29 21:36:10 imilh Exp $ */
 
 /*
- * Copyright (c) 2009, 2010, 2011 The NetBSD Foundation, Inc.
+ * Copyright (c) 2009, 2010, 2011, 2012 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * This code is derived from software contributed to The NetBSD Foundation
@@ -51,14 +51,15 @@ check_yesno(uint8_t default_answer)
 		const char		charval;
 	} answer[] = { { ANSW_NO, 'n' }, { ANSW_YES, 'y' } };
 
-	uint8_t			r, reverse_answer;
-	int				c;
+	uint8_t	r, reverse_answer;
+	int		c;
 
 	if (yesflag)
 		return ANSW_YES;
 	else if (noflag)
 		return ANSW_NO;
 
+	/* reverse answer is default's answer opposite (you don't say!) */
 	reverse_answer = (default_answer == ANSW_YES) ? ANSW_NO : ANSW_YES;
 
 	if (default_answer == answer[ANSW_YES].numval)
@@ -66,11 +67,18 @@ check_yesno(uint8_t default_answer)
 	else
 		printf(MSG_PROCEED_NO);
 
-	if ((c = getchar()) == answer[reverse_answer].charval)
-		r = answer[reverse_answer].numval;
-	else
+	c = tolower(getchar());
+	
+	/* default answer */
+	if (c == answer[default_answer].charval || c == '\n')
 		r = answer[default_answer].numval;
-
+	/* reverse answer */
+	else if (c == answer[reverse_answer].charval)
+		r = answer[reverse_answer].numval;
+	/* bad key was given, default to No */
+	else
+		r = ANSW_NO;
+	
 	/* avoid residual char */
 	if (c != '\n')
 		while((c = getchar()) != '\n' && c != EOF)
@@ -679,45 +687,35 @@ static char *
 narrow_match(Pkglist *opkg)
 {
 	Pkglist	*pkglist;
-	char	*best_match, *preferred;
-	unsigned int		i;
-	size_t  fullpkglen, r_fullpkglen, matchlen;
+	char	*best_match;
 
-	matchlen = 0;
-	fullpkglen = strlen(opkg->full);
-
-	preferred = read_preferred(opkg->name);
-	best_match = NULL;
+	/* for now, best match is old package itself */
+	XSTRDUP(best_match, opkg->full);
 
 	SLIST_FOREACH(pkglist, &r_plisthead, next) {
+		/* not the same pkgname, next */
 		if (strcmp(opkg->name, pkglist->name) != 0)
 			continue;
-
 		/*
 		 * if PKGPATH does not match, do not try to update (mysql 5.1/5.5)
 		 */
 		if (strcmp(opkg->pkgpath, pkglist->pkgpath) != 0)
-				continue;
-
-		r_fullpkglen = strlen(pkglist->full);
-
-		/* we already have his package, or installed version is greater */
-		if (strcmp(opkg->full, pkglist->full) >= 0)
 			continue;
 
-		/* match as long as we can */
-		for (i = 0; i < fullpkglen && i < r_fullpkglen &&
-				 opkg->full[i] == pkglist->full[i];
-			 i++);
+		/* same package version, next */
+		if (strcmp(opkg->full, pkglist->full) == 0)
+			continue;
 
-		if (i > matchlen) {
+		/* second package is greater */
+		if (version_check(best_match, pkglist->full) == 2) {
 			XFREE(best_match);
-			matchlen = i;
-			XSTRDUP(best_match, pkglist->full);
+			XSTRDUP(best_match, pkglist->full);			
 		}
-
 	} /* SLIST_FOREACH remoteplisthead */
 
+	/* there was no upgrade candidate */
+	if (strcmp(best_match, opkg->full) == 0)
+		XFREE(best_match);
 
 	return best_match;
 }
@@ -751,7 +749,8 @@ record_upgrades(Plisthead *plisthead)
 void
 pkgin_upgrade(int uptype)
 {
-	Plisthead	*keeplisthead, *localplisthead;
+	Plistnumbered	*keeplisthead;
+	Plisthead	*localplisthead;
 	char		**pkgargs;
 
 	/* used for pkgin_install not to update database, this is done below */
@@ -768,7 +767,7 @@ pkgin_upgrade(int uptype)
 		localplisthead = &l_plisthead;
 	} else
 		/* upgrade only keepables packages */
-		localplisthead = keeplisthead;
+		localplisthead = keeplisthead->P_Plisthead;
 
 	pkgargs = record_upgrades(localplisthead);
 
@@ -780,7 +779,7 @@ pkgin_upgrade(int uptype)
 		if (uptype == UPGRADE_ALL) {
 			free_list(pkgargs);
 			/* record keep list */
-			pkgargs = record_upgrades(keeplisthead);
+			pkgargs = record_upgrades(keeplisthead->P_Plisthead);
 		}
 
 		(void)update_db(LOCAL_SUMMARY, pkgargs);
@@ -788,5 +787,6 @@ pkgin_upgrade(int uptype)
 
 	free_list(pkgargs);
 
-	free_pkglist(&keeplisthead, LIST);
+	free_pkglist(&keeplisthead->P_Plisthead, LIST);
+	free(keeplisthead);
 }
