@@ -1,7 +1,7 @@
-/* $Id: main.c,v 1.29 2012/05/28 10:56:27 imilh Exp $ */
+/* $Id: main.c,v 1.31 2012/07/29 10:49:45 imilh Exp $ */
 
 /*
- * Copyright (c) 2009, 2010, 2011 The NetBSD Foundation, Inc.
+ * Copyright (c) 2009, 2010, 2011, 2012 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * This code is derived from software contributed to The NetBSD Foundation
@@ -111,7 +111,7 @@ main(int argc, char *argv[])
 	argv += optind;
 
 	if (argc < 1) {
-		fprintf(stderr, MSG_MISSING_CMD);
+		fprintf(stderr, "%s\n", MSG_MISSING_CMD);
 		usage();
 		/* NOTREACHED */
 	}
